[evolution/gnome-3-38] e-editor.js: Correct variable name in EvoEditor.InsertSignature()



commit a3a53ecd70fb4624dbf076125e941c74855fe2a0
Author: Milan Crha <mcrha redhat com>
Date:   Wed Jan 13 15:16:31 2021 +0100

    e-editor.js: Correct variable name in EvoEditor.InsertSignature()
    
    Typo in the variable name, it was meant to be `uid`, but `id` was used
    in the code instead.

 data/webkit/e-editor.js | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)
---
diff --git a/data/webkit/e-editor.js b/data/webkit/e-editor.js
index 45bb2aa144..8f9334b54c 100644
--- a/data/webkit/e-editor.js
+++ b/data/webkit/e-editor.js
@@ -4914,7 +4914,7 @@ EvoEditor.InsertSignature = function(content, isHTML, canRepositionCaret, uid, f
                        signature = wrapper.firstElementChild;
 
                        /* When we are editing a message with signature, we need to unset the
                         * active signature id as if the signature in the message was edited
                         * by the user we would discard these changes. */
                        if (fromMessage && content && signature) {
                                if (checkChanged) {
@@ -4924,7 +4924,7 @@ EvoEditor.InsertSignature = function(content, isHTML, canRepositionCaret, uid, f
 
                                        if (signature.firstElementChild && 
!signature.firstElementChild.isEqualNode(sigSpan)) {
                                                /* Signature in the body is different than the one with the
                                                 * same id, so set the active signature to None and leave
                                                 * the signature that is in the body. */
                                                uid = "none";
                                                ignoreNextChange = true;
@@ -4933,13 +4933,13 @@ EvoEditor.InsertSignature = function(content, isHTML, canRepositionCaret, uid, f
                                        checkChanged = false;
                                        fromMessage = false;
                                } else {
-                                       /* Old messages will have the signature id in the name attribute, 
correct it. */
+                                       /* Old messages will have the signature uid in the name attribute, 
correct it. */
                                        if (signature.hasAttribute("name")) {
-                                               id = signature.getAttribute("name");
-                                               signature.id = id;
+                                               uid = signature.getAttribute("name");
+                                               signature.id = uid;
                                                signature.removeAttribute("name");
                                        } else {
-                                               id = signature.id;
+                                               uid = signature.id;
                                        }
 
                                        /* Keep the signature and check if is it the same
@@ -4914,7 +4914,7 @@ EvoEditor.InsertSignature = function(content, isHTML, canRepositionCaret, uid, f
 
                        /* When we are editing a message with signature, we need to unset the
-                        * active signature id as if the signature in the message was edited
+                        * active signature uid as if the signature in the message was edited
                         * by the user we would discard these changes. */
                        if (fromMessage && content && signature) {
@@ -4924,7 +4924,7 @@ EvoEditor.InsertSignature = function(content, isHTML, canRepositionCaret, uid, f
!signature.firstElementChild.isEqualNode(sigSpan)) {
                                                /* Signature in the body is different than the one with the
-                                                * same id, so set the active signature to None and leave
+                                                * same uid, so set the active signature to None and leave
                                                 * the signature that is in the body. */
                                                uid = "none";


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]